@@ -1,12 +1,16 @@
+
+
+
 my.sort <- function(x,index.return=FALSE,decreasing=FALSE) {
 	if(decreasing) 
-	x <- -x
-	y <- .Internal(qsort(x,index.return=index.return))
+		x <- -x
+	y <- sort(x, method="quick", index.return=index.return)
 	if(decreasing) 
-	y$x <- -y$x
+		y$x <- -y$x
 	y
 }
 
+
 ################################################################
 ###				step function                    			 ###
 ################################################################
